pub struct DataSource<T>where
T: Default + Serialization,{
pub kind: DataSourceKind,
pub paddles: HashMap<u8, TofPaddle>,
pub strips: HashMap<u32, TrackerStrip>,
pub rb_calibrations: HashMap<u8, RBCalibrations>,
pub reader: dyn DataReader<T>,
}Expand description
A generic data source which can digest all kinds of GAPS input data
The Datasource can combine all necessary meta information, such as information about paddles as well as calibration data for tracker and TOF.
Fields
kind: DataSourceKindpaddles: HashMap<u8, TofPaddle>strips: HashMap<u32, TrackerStrip>rb_calibrations: HashMap<u8, RBCalibrations>reader: dyn DataReader<T>Auto Trait Implementations
impl<T> !Freeze for DataSource<T>
impl<T> !RefUnwindSafe for DataSource<T>
impl<T> !Send for DataSource<T>
impl<T> !Sized for DataSource<T>
impl<T> !Sync for DataSource<T>
impl<T> !Unpin for DataSource<T>
impl<T> !UnsafeUnpin for DataSource<T>
impl<T> !UnwindSafe for DataSource<T>